(* Memory info for virtual domains.
   (C) Copyright 2008 Richard W.M. Jones, Red Hat Inc.
   http://libvirt.org/

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *)

open Printf

open Virt_mem_gettext.Gettext
open Virt_mem_utils
open Virt_mem_types

open Kernel_task_struct

let run debug { domname = domname; mem = mem } { net_devices = net_devices } =
  let net_devices = Option.get net_devices in

  (* Sort by device name. *)
  let cmp { netdev_name = n1 } { netdev_name = n2 } = compare n1 n2 in
  let net_devices = List.sort cmp net_devices in

  List.iter (
    fun netdev ->
      printf "%5s mtu %Ld\n"
	netdev.netdev_name
	netdev.netdev_mtu
  ) net_devices

let summary = s_"list network interfaces in virtual machine"
let description = s_"\
virt-ifconfig prints a network interfaces for virtual machines.
"

let () =
  Virt_mem.register "ifconfig" summary description ~needs_net_devices:true ~run
