(** Memory info for virtual domains. *)
(* Memory info for virtual domains.
   (C) Copyright 2008 Richard W.M. Jones, Red Hat Inc.
   http://libvirt.org/

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *)

val register :
  ?needs_ksyms:bool ->
  ?needs_utsname:bool ->
  ?needs_tasks:bool ->
  ?needs_net_devices:bool ->
  ?needs_everything:bool ->
  run:(bool -> Virt_mem_types.image -> Virt_mem_types.kdata -> unit) ->
  ?external_cmd:bool ->
  ?extra_args:(Arg.key * Arg.spec * Arg.doc) list ->
  ?argcheck:(bool -> unit) ->
  string -> string -> Arg.usage_msg ->
  unit
  (** Tools register themselves with this call.

      The required parameters are:
      - tool name (eg. "uname")
      - short summary
      - full usage message

      The boolean parameters specify what kernel structures the
      tool needs before it can run.  The main program will read
      these structures in before calling [~run].
      - [~needs_ksyms:true] if kernel symbols are needed
      - [~needs_utsname:true] if kernel version (utsname) is needed
      - [~needs_tasks:true] if all task_struct (processes) are needed
      - [~needs_net_devices:true] if all net devices are needed
      - [~needs_everything:true] if the tool requires as much as
      possible (but will not fail if we cannot determine everything)

      The [~run] function is the tool's run function.  This function
      is run once for each separate domain.  It may throw any exception,
      which is printed out, but does not abort the program.  (If for
      some reason you need to abort the whole program, call [exit].)

      Pass [~external_cmd:false] if this tool doesn't have an
      external 'virt-tool' link.

      Pass [~extra_args:...] if this tool needs extra command
      line options.

      Pass [~argcheck:...] so that the tool can do any additional
      parameter checks needed (eg. for [~extra_args]).
  *)

val main : unit -> unit
  (** Entry point for the combined virt-mem executable. *)
