(* Memory info for virtual domains.
   (C) Copyright 2008 Richard W.M. Jones, Red Hat Inc.
   http://libvirt.org/

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *)

open Printf

open Virt_mem_gettext.Gettext
open Virt_mem_utils
open Virt_mem_types

open Kernel_task_struct

let run debug { domname = domname; mem = mem } { tasks = tasks } =
  let tasks = Option.get tasks in

  (* Sort tasks by PID. *)
  let cmp { task_pid = p1 } { task_pid = p2 } = compare p1 p2 in
  let tasks = List.sort cmp tasks in

  printf "  PID STAT COMMAND\n";

  List.iter (
    fun task ->
      printf "%5Ld      %s\n" task.task_pid task.task_comm
  ) tasks

let summary = s_"list processes in virtual machine"
let description = s_"\
virt-ps prints a process listing for virtual machines running under
libvirt."

let () =
  Virt_mem.register "ps" summary description ~needs_tasks:true ~run
